@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,13 +55,12 @@ import javax.servlet.ServletException;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.html.HtmlService;
 import com.openexchange.mobile.configuration.generator.MobileConfigServlet;
 import com.openexchange.mobile.configuration.generator.configuration.ConfigurationException;
 import com.openexchange.mobile.configuration.generator.configuration.MobileConfigProperties;
 import com.openexchange.mobile.configuration.generator.configuration.Property;
-import com.openexchange.mobile.configuration.generator.services.MobileConfigServiceRegistry;
 import com.openexchange.osgi.HousekeepingActivator;
-import com.openexchange.osgi.ServiceRegistry;
 import com.openexchange.templating.TemplateService;
 import com.openexchange.threadpool.ThreadPoolService;
 
@@ -74,6 +73,8 @@ public class Activator extends HousekeepingActivator {
 
     public static final String ALIAS = "/servlet/mobileconfig";
 
+    private boolean registered;
+
     /**
      * Initializes a new {@link Activator}.
      */
@@ -83,37 +84,24 @@ public class Activator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] {
-            ConfigurationService.class, TemplateService.class, ThreadPoolService.class, HttpService.class };
+        return new Class<?>[] { ConfigurationService.class, TemplateService.class, ThreadPoolService.class, HttpService.class, HtmlService.class };
     }
 
     @Override
     protected void handleAvailability(final Class<?> clazz) {
         LOG.info("Re-available service: {}", clazz.getName());
-        MobileConfigServiceRegistry.getServiceRegistry().addService(clazz, getService(clazz));
         register();
     }
 
     @Override
     protected void handleUnavailability(final Class<?> clazz) {
         LOG.warn("Absent service: {}", clazz.getName());
-        MobileConfigServiceRegistry.getServiceRegistry().removeService(clazz);
         unregister();
     }
 
     @Override
     protected void startBundle() throws Exception {
-        {
-            final ServiceRegistry registry = MobileConfigServiceRegistry.getServiceRegistry();
-            registry.clearRegistry();
-            final Class<?>[] classes = getNeededServices();
-            for (int i = 0; i < classes.length; i++) {
-                final Object service = getService(classes[i]);
-                if (null != service) {
-                    registry.addService(classes[i], service);
-                }
-            }
-        }
+        Services.setServiceLookup(this);
         // Check configuration
         checkConfiguration();
         // Test encoding:
@@ -127,18 +115,25 @@ public class Activator extends HousekeepingActivator {
     }
 
     private void checkConfiguration() throws ConfigurationException {
-        MobileConfigProperties.check(MobileConfigServiceRegistry.getServiceRegistry(), Property.values(), "Mobileconfig");
+        MobileConfigProperties.check(Property.values(), "Mobileconfig");
     }
 
     @Override
     protected void stopBundle() throws Exception {
         unregister();
-
-        MobileConfigServiceRegistry.getServiceRegistry().clearRegistry();
+        Services.setServiceLookup(null);
+        super.stopBundle();
     }
 
-    private void register() {
-        final HttpService service = getService(HttpService.class);
+    /**
+     * Registers the servlet.
+     */
+    private synchronized void register() {
+        if (registered) {
+            return;
+        }
+
+        HttpService service = getService(HttpService.class);
         if (null == service) {
             return;
         }
@@ -152,8 +147,15 @@ public class Activator extends HousekeepingActivator {
         LOG.info("MobileConfig servlet registered");
     }
 
-    public void unregister() {
-        final HttpService service = getService(HttpService.class);
+    /**
+     * Unregisters the servlet.
+     */
+    private synchronized void unregister() {
+        if (!registered) {
+            return;
+        }
+
+        HttpService service = getService(HttpService.class);
         if (null != service) {
             service.unregister(ALIAS);
         }
